@@ -4,21 +4,20 @@ set -ex
 
 CMD=oc
 
-ANNOTATION_EXP="/^  namespace: ns.*$/a\  annotations:\n    vm.kubevirt.io/template: some-template"
+LABEL_EXP="/^  namespace: ns.*$/a\  labels:\n    vm.kubevirt.io/template: some-template"
 
 # create 100 VMs
 for ns in {001..005}; do
   sed "s#__NS__#${ns}#g" automation/ns.yaml | ${CMD} apply -f -
   for vm in {001..020}; do
+    EXP=
     n=$(echo $vm | sed "s|^0*||")
     if [[ $(($n%2)) -eq 0 ]]; then
-      sed -e "s#__NS__#${ns}#g" -e "s|##VM##|${vm}|g" -e "${ANNOTATION_EXP}" automation/vm.yaml >> "vms_ns${ns}.yaml"
-    else
-      sed -e "s#__NS__#${ns}#g" -e "s|##VM##|${vm}|g" automation/vm.yaml >> "vms_ns${ns}.yaml"
+      EXP="; ${LABEL_EXP}"
     fi
+    sed -e "s#__NS__#${ns}#g; s|##VM##|${vm}|g${EXP}" automation/vm.yaml | ${CMD} apply -f -
 
   done
-  ${CMD} apply -f "vms_ns${ns}.yaml"
 
   # start 5 VMs
   if [[ ${ns} -le 5 ]]; then
